@@ -10,7 +10,7 @@
 //! Add `zigarg` to `Cargo.toml` as a dependency
 //! ```ignore
 //! [dependencies]
-//! zigarg = "1.0.0"
+//! zigarg = "1.1.0"
 //! ```
 //! Capture user's arguments by adding the code below, after you have added zigarg to your dependencies:
 //! ```ignore
@@ -30,7 +30,7 @@
 //! ```
 //! Check documentation of the Arguments struct below for more...
 
-use std::{env, ops::Deref};
+use std::{env, ops::Deref, usize};
 
 #[derive(Debug)]
 ///`Struct` that contains the arguments provided by the user
@@ -130,4 +130,9 @@ impl Arguments {
         }
         false
     }
+
+    ///Returns the rest of the arguments based on provided index
+    pub fn get_after_index(&self, query: usize) -> Vec<String> {
+        self.0[query..].iter().map(|x| x.to_owned()).collect()
+    }
 }
